@@ -1,5 +1,9 @@
 pub use k8s_openapi::apimachinery::pkg::apis::meta::v1::ObjectMeta;
-use k8s_openapi::{api::core::v1::ObjectReference, apimachinery::pkg::apis::meta::v1::OwnerReference};
+use k8s_openapi::{
+    api::core::v1::ObjectReference,
+    apimachinery::pkg::apis::meta::v1::{ManagedFieldsEntry, OwnerReference, Time},
+};
+
 use std::{borrow::Cow, collections::BTreeMap};
 
 /// An accessor trait for a kubernetes Resource.
@@ -82,6 +86,22 @@ pub trait Resource {
             ..Default::default()
         }
     }
+
+    /// Generates a controller owner reference pointing to this resource
+    ///
+    /// Note: this returns an `Option`, but for objects populated from the apiserver,
+    /// this Option can be safely unwrapped.
+    fn controller_owner_ref(&self, dt: &Self::DynamicType) -> Option<OwnerReference> {
+        let meta = self.meta();
+        Some(OwnerReference {
+            api_version: Self::api_version(dt).to_string(),
+            kind: Self::kind(dt).to_string(),
+            name: meta.name.clone()?,
+            uid: meta.uid.clone()?,
+            controller: Some(true),
+            ..OwnerReference::default()
+        })
+    }
 }
 
 /// Implement accessor trait for any ObjectMeta-using Kubernetes Resource
@@ -138,6 +158,10 @@ pub trait ResourceExt: Resource {
     /// Unique ID (if you delete resource and then create a new
     /// resource with the same name, it will have different ID)
     fn uid(&self) -> Option<String>;
+    /// Returns the creation timestamp
+    ///
+    /// This is guaranteed to exist on resources received by the apiserver.
+    fn creation_timestamp(&self) -> Option<Time>;
     /// Returns resource labels
     fn labels(&self) -> &BTreeMap<String, String>;
     /// Provides mutable access to the labels
@@ -154,6 +178,10 @@ pub trait ResourceExt: Resource {
     fn finalizers(&self) -> &[String];
     /// Provides mutable access to the finalizers
     fn finalizers_mut(&mut self) -> &mut Vec<String>;
+    /// Returns managed fields
+    fn managed_fields(&self) -> &[ManagedFieldsEntry];
+    /// Provides mutable access to managed fields
+    fn managed_fields_mut(&mut self) -> &mut Vec<ManagedFieldsEntry>;
 }
 
 // TODO: replace with ordinary static when BTreeMap::new() is no longer
@@ -178,6 +206,10 @@ impl<K: Resource> ResourceExt for K {
         self.meta().uid.clone()
     }
 
+    fn creation_timestamp(&self) -> Option<Time> {
+        self.meta().creation_timestamp.clone()
+    }
+
     fn labels(&self) -> &BTreeMap<String, String> {
         self.meta().labels.as_ref().unwrap_or(&*EMPTY_MAP)
     }
@@ -209,4 +241,12 @@ impl<K: Resource> ResourceExt for K {
     fn finalizers_mut(&mut self) -> &mut Vec<String> {
         self.meta_mut().finalizers.get_or_insert_with(Vec::new)
     }
+
+    fn managed_fields(&self) -> &[ManagedFieldsEntry] {
+        self.meta().managed_fields.as_deref().unwrap_or_default()
+    }
+
+    fn managed_fields_mut(&mut self) -> &mut Vec<ManagedFieldsEntry> {
+        self.meta_mut().managed_fields.get_or_insert_with(Vec::new)
+    }
 }
